pub struct CAMERA_IMAGE_CAPTURED_DATA {
pub time_utc: u64,
pub time_boot_ms: u32,
pub lat: i32,
pub lon: i32,
pub alt: i32,
pub relative_alt: i32,
pub q: [f32; 4],
pub image_index: i32,
pub camera_id: u8,
pub capture_result: MavBool,
pub file_url: CharArray<205>,
}dialect-storm32 only.Expand description
Information about a captured image. This is emitted every time a message is captured. MAV_CMD_REQUEST_MESSAGE can be used to (re)request this message for a specific sequence number or range of sequence numbers: MAV_CMD_REQUEST_MESSAGE.param2 indicates the sequence number the first image to send, or set to -1 to send the message for all sequence numbers. MAV_CMD_REQUEST_MESSAGE.param3 is used to specify a range of messages to send: set to 0 (default) to send just the the message for the sequence number in param 2, set to -1 to send the message for the sequence number in param 2 and all the following sequence numbers, set to the sequence number of the final message in the range.
ID: 263
Fields
time_utc: u64Timestamp (time since UNIX epoch) in UTC. 0 for unknown.
time_boot_ms: u32Timestamp (time since system boot).
lat: i32Latitude where image was taken
lon: i32Longitude where capture was taken
alt: i32Altitude (MSL) where image was taken
relative_alt: i32Altitude above ground
q: [f32; 4]Quaternion of camera orientation (w, x, y, z order, zero-rotation is 1, 0, 0, 0)
image_index: i32Zero based index of this image (i.e. a new image will have index CAMERA_CAPTURE_STATUS.image count -1)
camera_id: u8Camera id of a non-MAVLink camera attached to an autopilot (1-6). 0 if the component is a MAVLink camera (with its own component id). Field name is usually camera_device_id.
capture_result: MavBoolImage was captured successfully (MAV_BOOL_TRUE). Values not equal to 0 or 1 are invalid.
file_url: CharArray<205>URL of image taken. Either local storage or http://foo.jpg if camera provides an HTTP interface.
Implementations