pub struct ESTIMATOR_STATUS_DATA {
pub time_usec: u64,
pub vel_ratio: f32,
pub pos_horiz_ratio: f32,
pub pos_vert_ratio: f32,
pub mag_ratio: f32,
pub hagl_ratio: f32,
pub tas_ratio: f32,
pub pos_horiz_accuracy: f32,
pub pos_vert_accuracy: f32,
pub flags: EstimatorStatusFlags,
}dialect-storm32 only.Expand description
Estimator status message including flags, innovation test ratios and estimated accuracies. The flags message is an integer bitmask containing information on which EKF outputs are valid. See the ESTIMATOR_STATUS_FLAGS enum definition for further information. The innovation test ratios show the magnitude of the sensor innovation divided by the innovation check threshold. Under normal operation the innovation test ratios should be below 0.5 with occasional values up to 1.0. Values greater than 1.0 should be rare under normal operation and indicate that a measurement has been rejected by the filter. The user should be notified if an innovation test ratio greater than 1.0 is recorded. Notifications for values in the range between 0.5 and 1.0 should be optional and controllable by the user.
ID: 230
Fields
time_usec: u64Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
vel_ratio: f32Velocity innovation test ratio
pos_horiz_ratio: f32Horizontal position innovation test ratio
pos_vert_ratio: f32Vertical position innovation test ratio
mag_ratio: f32Magnetometer innovation test ratio
hagl_ratio: f32Height above terrain innovation test ratio
tas_ratio: f32True airspeed innovation test ratio
pos_horiz_accuracy: f32Horizontal position 1-STD accuracy relative to the EKF local origin
pos_vert_accuracy: f32Vertical position 1-STD accuracy relative to the EKF local origin
flags: EstimatorStatusFlagsBitmap indicating which EKF outputs are valid.
Implementations