pub struct MLRS_RADIO_LINK_STATS_DATA {Show 16 fields
pub flags: MlrsRadioLinkStatsFlags,
pub target_system: u8,
pub target_component: u8,
pub rx_LQ_rc: u8,
pub rx_LQ_ser: u8,
pub rx_rssi1: u8,
pub rx_snr1: i8,
pub tx_LQ_ser: u8,
pub tx_rssi1: u8,
pub tx_snr1: i8,
pub rx_rssi2: u8,
pub rx_snr2: i8,
pub tx_rssi2: u8,
pub tx_snr2: i8,
pub frequency1: f32,
pub frequency2: f32,
}dialect-storm32 only.Expand description
Radio link statistics for a MAVLink RC receiver or transmitter and other links. Tx: ground-side device, Rx: vehicle-side device. The message is normally emitted in regular time intervals upon each actual or expected reception of an over-the-air data packet on the link. A MAVLink RC receiver should emit it shortly after it emits a RADIO_RC_CHANNELS message (if it is emitting that message). Per default, rssi values are in MAVLink units: 0 represents weakest signal, 254 represents maximum signal, UINT8_MAX represents unknown. The RADIO_LINK_STATS_FLAGS_RSSI_DBM flag is set if the rssi units are negative dBm: 1..254 correspond to -1..-254 dBm, 0 represents no reception, UINT8_MAX represents unknown. The target_system field should normally be set to the system id of the system the link is connected to, typically the flight controller. The target_component field can normally be set to 0, so that all components of the system can receive the message. Note: The frequency fields are extensions to ensure that they are located at the end of the serialized payload and subject to MAVLink’s trailing-zero trimming.
ID: 60045
Fields
flags: MlrsRadioLinkStatsFlagsRadio link statistics flags.
target_system: u8System ID (ID of target system, normally flight controller).
target_component: u8Component ID (normally 0 for broadcast).
rx_LQ_rc: u8Link quality of RC data stream from Tx to Rx. Values: 1..100, 0: no link connection, UINT8_MAX: unknown.
rx_LQ_ser: u8Link quality of serial MAVLink data stream from Tx to Rx. Values: 1..100, 0: no link connection, UINT8_MAX: unknown.
rx_rssi1: u8Rssi of antenna 1. 0: no reception, UINT8_MAX: unknown.
rx_snr1: i8Noise on antenna 1. Radio link dependent. INT8_MAX: unknown.
tx_LQ_ser: u8Link quality of serial MAVLink data stream from Rx to Tx. Values: 1..100, 0: no link connection, UINT8_MAX: unknown.
tx_rssi1: u8Rssi of antenna 1. 0: no reception. UINT8_MAX: unknown.
tx_snr1: i8Noise on antenna 1. Radio link dependent. INT8_MAX: unknown.
rx_rssi2: u8Rssi of antenna 2. 0: no reception, UINT8_MAX: use rx_rssi1 if it is known else unknown.
rx_snr2: i8Noise on antenna 2. Radio link dependent. INT8_MAX: use rx_snr1 if it is known else unknown.
tx_rssi2: u8Rssi of antenna 2. 0: no reception. UINT8_MAX: use tx_rssi1 if it is known else unknown.
tx_snr2: i8Noise on antenna 2. Radio link dependent. INT8_MAX: use tx_snr1 if it is known else unknown.
frequency1: f32Frequency on antenna1 in Hz. 0: unknown.
frequency2: f32Frequency on antenna2 in Hz. 0: unknown.
Implementations