pub struct OPEN_DRONE_ID_MESSAGE_PACK_DATA {
pub target_system: u8,
pub target_component: u8,
pub id_or_mac: [u8; 20],
pub single_message_size: u8,
pub msg_pack_size: u8,
pub messages: [u8; 225],
}dialect-storm32 only.Expand description
An OpenDroneID message pack is a container for multiple encoded OpenDroneID messages (i.e. not in the format given for the above message descriptions but after encoding into the compressed OpenDroneID byte format). Used e.g. when transmitting on Bluetooth 5.0 Long Range/Extended Advertising or on WiFi Neighbor Aware Networking or on WiFi Beacon.
ID: 12915
Fields
target_system: u8System ID (0 for broadcast).
target_component: u8Component ID (0 for broadcast).
id_or_mac: [u8; 20]Only used for drone ID data received from other UAs. See detailed description at https://mavlink.io/en/services/opendroneid.html.
single_message_size: u8This field must currently always be equal to 25 (bytes), since all encoded OpenDroneID messages are specified to have this length.
msg_pack_size: u8Number of encoded messages in the pack (not the number of bytes). Allowed range is 1 - 9.
messages: [u8; 225]Concatenation of encoded OpenDroneID messages. Shall be filled with nulls in the unused portion of the field.
Implementations